==> mono-2.4.3.tar.bz2: mono-2.4.3/mcs/class/System.ServiceModel/System.ServiceModel.Channels/OutputChannelBase.cs <==
//
// OutputChannelBase.cs
//
// Author: Atsushi Enomoto (atsushi@ximian.com)
//
// Copyright (C) 2007 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
using System;
using System.ServiceModel;

namespace System.ServiceModel.Channels
{
	internal abstract class OutputChannelBase : ChannelBase, IOutputChannel
	{
		ChannelFactoryBase channel_factory;

		public OutputChannelBase (ChannelFactoryBase factory)
			: base (factory)
		{
			this.channel_factory = factory;
		}

		protected internal override TimeSpan DefaultCloseTimeout {
			get { return channel_factory.DefaultCloseTimeout; }
		}

		protected internal override TimeSpan DefaultOpenTimeout {
			get { return channel_factory.DefaultOpenTimeout; }
		}

		// IOutputChannel
		public abstract EndpointAddress RemoteAddress { get; }

		public abstract Uri Via { get; }

		public IAsyncResult BeginSend (Message message, AsyncCallback callback, object state)
		{
			return BeginSend (message, channel_factory.DefaultSendTimeout, callback, state);
		}

		public abstract IAsyncResult BeginSend (Message message, TimeSpan timeout, AsyncCallback callback, object state);

		public abstract void EndSend (IAsyncResult result);

		public void Send (Message message)
		{
			Send (message, channel_factory.DefaultSendTimeout);
		}

		public abstract void Send (Message message, TimeSpan timeout);
	}
}

==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/System.ServiceModel/System.ServiceModel.Channels/OutputChannelBase.cs <==
//
// OutputChannelBase.cs
//
// Author: Atsushi Enomoto (atsushi@ximian.com)
//
// Copyright (C) 2007 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
using System;
using System.ServiceModel;

namespace System.ServiceModel.Channels
{
	internal abstract class OutputChannelBase : ChannelBase, IOutputChannel
	{
		ChannelFactoryBase channel_factory;

		public OutputChannelBase (ChannelFactoryBase factory, EndpointAddress remoteAddress, Uri via)
			: base (factory)
		{
			this.channel_factory = factory;
			RemoteAddress = remoteAddress;
			Via = via;
		}

		protected internal override TimeSpan DefaultCloseTimeout {
			get { return channel_factory.DefaultCloseTimeout; }
		}

		protected internal override TimeSpan DefaultOpenTimeout {
			get { return channel_factory.DefaultOpenTimeout; }
		}

		// IOutputChannel
		public EndpointAddress RemoteAddress { get; private set; }

		public Uri Via { get; private set; }

		public IAsyncResult BeginSend (Message message, AsyncCallback callback, object state)
		{
			return BeginSend (message, channel_factory.DefaultSendTimeout, callback, state);
		}

		public abstract IAsyncResult BeginSend (Message message, TimeSpan timeout, AsyncCallback callback, object state);

		public abstract void EndSend (IAsyncResult result);

		public void Send (Message message)
		{
			Send (message, channel_factory.DefaultSendTimeout);
		}

		public virtual void Send (Message message, TimeSpan timeout)
		{
			EndSend (BeginSend (message, timeout, null, null));
		}
	}
}
